PROGRAM Compute_Fcoll
  USE cosmo
  USE linearpk
  USE sigma
  USE growth
  ! A sample program for computing a collapse fraction, 
  !    fcoll(>m,z) = (1/rho_m0) int_m^\infty dM M dn(z)/dM 
  !                = int_{numin(z)}^\infty dlnnu mf(lnnu)
  ! as a function of redshift, z. This version uses the Sheth-Tormen
  ! mass function, which is defined for M200d (200 times the 
  ! mean mass density of the universe).
  !
  ! The output file, "redshift_fcoll.txt", contains:
  ! 1st column: z
  ! 2nd column: fcoll(>m,z), numerically integrated
  !
  ! January 2, 2010: E.Komatsu
  IMPLICIT none
  double precision :: deltac=1.6865d0,mf,m200d
  double precision :: lnnu,rombint,tol=1d-10,pi=3.1415926535d0
  real :: chebev
  real :: lnsigma2,lnRh
  double precision :: Rh,zin,zout,g,scalefactor
  character(len=128) :: filename
  integer :: i,n
  external g,mf,rombint
! Specify three cosmological parameters
! The data type has been defined in MODULE cosmo.
  ode0=0.723d0
  om0=0.277d0
  w=-1d0
  print*,'omega matter=',om0
  print*,'omega de=',ode0
  print*,'w=',w
! read in and tabulate P(k)
  filename='wmap5baosn_max_likelihood_matterpower_at_z=30.dat'
  n=896 ! # of lines in the file
  CALL open_linearpk(filename,n)
  zin=30d0
! fit sigma^2(R) to Chebyshev polynomials
  CALL compute_sigma2
  CALL close_linearpk
! compute and tabulate the growth factor
  CALL setup_growth
! ask for the minimum virial mass
  print*,'Minimum mass (200 times the mean mass density of the universe),'
  print*,'M_{min,200d}, in units of h^-1 Msun?'
  read*,m200d
  Rh=(3d0*m200d/4d0/pi/om0/2.775d11)**(1d0/3d0) ! h^-1 Mpc
  lnRh=real(dlog(Rh))
  lnsigma2=CHEBEV(lnR1,lnR2,c,ndim,lnRh) ! ln(sigma^2)
  open(1,file='redshift_fcoll.txt',status='unknown')
! loop over redshift
  do i=0,300
     zout=dble(i)*1d-1
     scalefactor=g(zout)/g(zin)*(1d0+zin)/(1d0+zout)
     lnnu=2d0*dlog(deltac)-dble(lnsigma2)-2d0*dlog(scalefactor) ! ln(nu)
     write(1,'(2E13.5)') zout,rombint(mf,lnnu,1d1,tol)
  enddo
  close(1)
END PROGRAM Compute_Fcoll
